document.addEventListener('DOMContentLoaded', () => {
    const fetchSettings = async () => {
        try {
            const response = await fetch(`${ajaxurl}?action=falling_emojis_settings`);
            const settings = await response.json();
            return settings;
        } catch (error) {
            console.error('Error fetching Falling Emojis settings:', error);
            return { emoji_list: ['🌟', '🌈', '🍂', '😄', '🚀'], speed: 200, density: 1, enabled: true };
        }
    };

    fetchSettings().then(settings => {
        if (!settings.enabled) {
            console.log('Falling emojis effect is disabled.');
            return; // Exit if the effect is disabled
        }

        const emojis = settings.emoji_list || ['🌟', '🌈', '🍂', '😄', '🚀'];
        const speed = settings.speed || 200;
        const density = settings.density || 1;

        const createEmoji = () => {
            const emoji = document.createElement('div');
            emoji.textContent = getRandomEmoji();
            emoji.classList.add('falling-emoji');
            emoji.style.position = 'fixed';
            emoji.style.top = '-50px';
            emoji.style.left = `${Math.random() * 100}vw`;
            emoji.style.fontSize = `${Math.random() * 24 + 16}px`;
            emoji.style.animation = `fall ${Math.random() * 3 + 2}s linear`;
            emoji.style.zIndex = '9999';

            document.body.appendChild(emoji);

            emoji.addEventListener('animationend', () => {
                emoji.remove();
            });
        };

        const getRandomEmoji = () => {
            return emojis[Math.floor(Math.random() * emojis.length)];
        };

        const createFallingEmojis = () => {
            setInterval(() => {
                for (let i = 0; i < density; i++) {
                    createEmoji();
                }
            }, speed);
        };

        const style = document.createElement('style');
        style.textContent = `
            @keyframes fall {
                0% {
                    transform: translateY(0);
                    opacity: 1;
                }
                100% {
                    transform: translateY(100vh);
                    opacity: 0;
                }
            }

            .falling-emoji {
                pointer-events: none;
            }
        `;
        document.head.appendChild(style);

        createFallingEmojis();
    });
});
